#ifndef MDC_CAM_CLASS_H
#define MDC_CAM_CLASS_H
#include "camera.h"
#include <vector>
#include <array>
#include <ara/log/logging.h>
#include <thread>
#include "mdc_mbuf.h"
#include "camera_pool.h"

class MDCCamera
{
public:
    MDCCamera(std::shared_ptr<CameraPool> pool = nullptr);
    void init(std::vector<mdc::camera::CameraAccessConfig> &configs);
    std::vector<CameraImageResult> getCameraImages();
    uint8_t getCameraImagesArray(std::array<CameraImageResult, 4> &result);
    uint8_t getCameraImagesArrayVector(std::array<CameraImageResult, 4> &result);
    uint8_t getCameraYUVBuffer(void **buffer, size_t &length, mdc::camera::CameraData &image);
    void runCameras();

protected:
    ara::log::Logger &logger{ara::log::CreateLogger("SWM_CAMERA", "SoftwareMotion Camera Module", ara::log::LogLevel::kInfo)};
    bool ready = false;

private:
    int image_timeout = 1000;
    const uint8_t camStartId = 8;
    uint8_t getRawId(uint8_t id);
    std::shared_ptr<CameraPool> pool_;
    const uint16_t cameraSleepDuration = 45;
    std::array<CameraImageResult, 4> data;
    std::thread act{};
};
#endif
